@@ -7,7 +7,8 @@ cols <- c(
 test_that("MLB Game Status Codes", {
   skip_on_cran()
   
-  x <- mlb_game_status_codes()
+  x <- mlb_game_status_codes() %>% 
+    dplyr::select(tidyr::all_of(cols))
   
   expect_equal(colnames(x), cols)
   expect_s3_class(x, "data.frame")
